@@ -3,7 +3,7 @@ BEGIN {
   $OX::Meta::Role::Class::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $OX::Meta::Role::Class::VERSION = '0.07';
+  $OX::Meta::Role::Class::VERSION = '0.08';
 }
 use Moose::Role;
 use namespace::autoclean;
@@ -49,11 +49,21 @@ sub all_middleware {
            $self->linearized_isa;
 }
 
+sub clear_app_state {
+    my $self = shift;
+    $self->_clear_routes;
+    $self->_clear_mounts;
+    $self->_clear_mixed_conflicts;
+    $self->_clear_middleware;
+    $self->_clear_route_builders;
+}
+
 =pod
 
 =for Pod::Coverage
   router_config
   all_middleware
+  clear_app_state
 
 =cut
 
