@@ -3,7 +3,7 @@ BEGIN {
   $OX::Meta::Role::HasRoutes::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $OX::Meta::Role::HasRoutes::VERSION = '0.07';
+  $OX::Meta::Role::HasRoutes::VERSION = '0.08';
 }
 use Moose::Role;
 use namespace::autoclean;
@@ -22,8 +22,9 @@ has routes => (
     isa     => 'ArrayRef[OX::Meta::Route|OX::Meta::Conflict]',
     default => sub { [] },
     handles => {
-        routes     => 'elements',
-        _add_route => 'push',
+        routes        => 'elements',
+        _add_route    => 'push',
+        _clear_routes => 'clear',
     },
 );
 
@@ -32,9 +33,10 @@ has mounts => (
     isa     => 'ArrayRef[OX::Meta::Mount|OX::Meta::Conflict]',
     default => sub { [] },
     handles => {
-        mounts     => 'elements',
-        has_mounts => 'count',
-        _add_mount => 'push',
+        mounts        => 'elements',
+        has_mounts    => 'count',
+        _add_mount    => 'push',
+        _clear_mounts => 'clear',
     },
 );
 
@@ -43,8 +45,9 @@ has mixed_conflicts => (
     isa     => 'ArrayRef[OX::Meta::Conflict]',
     default => sub { [] },
     handles => {
-        mixed_conflicts     => 'elements',
-        _add_mixed_conflict => 'push',
+        mixed_conflicts        => 'elements',
+        _add_mixed_conflict    => 'push',
+        _clear_mixed_conflicts => 'clear',
     },
 );
 
